/**
 *  Copyright 2005-2006 Aviad Ben Dov
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */


package com.crp.whirl;

public enum MathCommand implements Command {
	Noop { public void execute(Machine machine) { } },
	Load { public void execute(Machine machine) { machine.mathWheel.value = machine.memory.get(); } },
	Store { public void execute(Machine machine) { machine.memory.set(machine.mathWheel.value); } },
	Add { public void execute(Machine machine) { machine.mathWheel.value += machine.memory.get(); } },
	Mult { public void execute(Machine machine) { machine.mathWheel.value *= machine.memory.get(); } },
	Div { public void execute(Machine machine) { machine.mathWheel.value /= machine.memory.get(); } },
	Zero { public void execute(Machine machine) { machine.mathWheel.value = 0; } },
	IsLesser { 
		public void execute(Machine machine) { 
			machine.mathWheel.value = machine.mathWheel.value < machine.memory.get() ? 1 : 0;
		}
	},
	IsGreater { 
		public void execute(Machine machine) {
			machine.mathWheel.value = machine.mathWheel.value > machine.memory.get() ? 1 : 0;
		}
	},
	IsEqual { 
		public void execute(Machine machine) {
			machine.mathWheel.value = machine.mathWheel.value == machine.memory.get() ? 1 : 0;
		}
	},
	Not {
		public void execute(Machine machine) {
			machine.mathWheel.value = machine.mathWheel.value != 0 ? 0 : 1;
		}
	},
	Neg { public void execute(Machine machine) { machine.mathWheel.value = -machine.mathWheel.value; } };
}

