/**
 *  Copyright 2005-2006 Aviad Ben Dov
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */


package com.crp.whirl;

import java.util.List;
import java.util.ArrayList;

public final class Memory extends MachinePart {
	private List<Integer> data = new ArrayList<Integer>();
	int ptr = 0;

	public int peek(int offset) {
		int at = ptr + offset;

		if (at >= data.size()) return 0;
		
		Integer val = data.get(at);

		return val == null ? 0 : val;
	}

	public int get() {
		if (ptr >= data.size()) return 0;

		Integer val = data.get(ptr);
		
		assert val != null;
		
		return val;
	}

	public void set(int val) { 
		increase(ptr);

		data.set(ptr, Integer.valueOf(val)); 
	}

	public void increase(int newsize) {
		int inc = newsize - data.size();
		while (inc-- >= 0) data.add(0);	
	}
			

	public int offset(int where) { return where - ptr; }

	public void move(int offset) { ptr += offset; }
}

